import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import classNames from 'classnames';
import { forwardRef, cloneElement, createContext, useContext, useState, useEffect, useRef } from 'react';
import { Button as Button$1 } from 'reakit/Button';
import { Checkbox as Checkbox$1 } from 'reakit/Checkbox';
import { MenuButton, MenuItem, Menu, MenuSeparator, useMenuState } from 'reakit/Menu';
import { Input as Input$1 } from 'reakit/Input';
import { DialogDisclosure, DialogBackdrop, Dialog, useDialogState } from 'reakit/Dialog';
import { CompositeItem, useCompositeState, Composite } from 'reakit/Composite';
import { useCombobox, useSelect } from 'downshift';
import { Separator as Separator$1 } from 'reakit/Separator';
import { Role } from 'reakit/Role';
import { useDisclosureState, DisclosureContent, Disclosure } from 'reakit/Disclosure';
import AnimateHeight from 'react-animate-height';
import { Tab, TabList, TabPanel, useTabState } from 'reakit/Tab';

function AlertTitle(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return jsx("h4", Object.assign({
    className: classNames('font-medium', className)
  }, {
    children: children
  }), void 0);
}

function AlertIcon(_ref) {
  var variant = _ref.variant,
      className = _ref.className;
  var iconClasses = classNames('w-5 h-5', className);

  if (variant === 'success') {
    return jsx("svg", Object.assign({
      className: classNames('text-success-700', iconClasses),
      fill: "none",
      stroke: "currentColor",
      viewBox: "0 0 24 24",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: jsx("path", {
        d: "M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z",
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 2
      }, void 0)
    }), void 0);
  }

  if (variant === 'danger') {
    return jsx("svg", Object.assign({
      className: classNames('text-danger-700', iconClasses),
      fill: "none",
      stroke: "currentColor",
      viewBox: "0 0 24 24",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: jsx("path", {
        d: "M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z",
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 2
      }, void 0)
    }), void 0);
  }

  if (variant === 'warning') {
    return jsx("svg", Object.assign({
      className: classNames('text-warning-700', iconClasses),
      fill: "none",
      stroke: "currentColor",
      viewBox: "0 0 24 24",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: jsx("path", {
        d: "M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z",
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 2
      }, void 0)
    }), void 0);
  }

  if (variant === 'info') {
    return jsx("svg", Object.assign({
      className: classNames('text-info-700', iconClasses),
      fill: "none",
      stroke: "currentColor",
      viewBox: "0 0 24 24",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: jsx("path", {
        d: "M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z",
        strokeLinecap: "round",
        strokeLinejoin: "round",
        strokeWidth: 2
      }, void 0)
    }), void 0);
  }

  return null;
}

function Alert(_ref) {
  var variant = _ref.variant,
      children = _ref.children,
      className = _ref.className;
  return jsx("div", Object.assign({
    className: classNames('py-3 px-4 rounded-xl', {
      'bg-success-50 text-success-700': variant === 'success',
      'bg-danger-50 text-danger-700': variant === 'danger',
      'bg-warning-50 text-warning-700': variant === 'warning',
      'bg-info-50 text-info-700': variant === 'info'
    }, className),
    role: "alert"
  }, {
    children: children
  }), void 0);
}

function Avatar(_ref) {
  var username = _ref.username,
      src = _ref.src,
      alt = _ref.alt,
      className = _ref.className,
      ring = _ref.ring;
  return jsx("img", {
    alt: alt || username + "'s Avatar",
    className: classNames('object-cover object-center w-10 h-10 rounded-full group-focus:ring-2 ring-primary-500', {
      'ring-2 ring-white': ring
    }, className),
    src: src
  }, void 0);
}
Avatar.defaultProps = {
  className: '',
  ring: false
};

function Badge(_ref) {
  var variant = _ref.variant,
      className = _ref.className,
      children = _ref.children,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'small' : _ref$size;
  return jsx("span", Object.assign({
    className: classNames('py-1 rounded-lg font-medium tracking-wider uppercase', {
      'bg-success-50 text-success-700': variant === 'success',
      'bg-danger-50 text-danger-700': variant === 'danger',
      'bg-warning-50 text-warning-700': variant === 'warning',
      'bg-info-50 text-info-700': variant === 'info',
      'px-2 text-xs': size === 'small',
      'px-3': size === 'large'
    }, className)
  }, {
    children: children
  }), void 0);
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

// --------------------
// UTILS
// --------------------

function forwardRefWithAs(component) {
  return forwardRef(component);
}

var buttonClasses = function buttonClasses(variant, size, primary, danger, rounded) {
  var contained = variant === 'contained';
  var outlined = variant === 'outlined';
  var text = variant === 'text';
  var primaryOrDanger = primary || danger;
  var outlineOrText = outlined || text;
  return classNames('focus:outline-none focus:ring-2 transition disabled:bg-opacity-75 disabled:cursor-default font-medium', {
    'ring-danger-500': danger,
    'ring-primary-500': !danger,
    'text-white': contained && primaryOrDanger,
    'bg-primary-500 hover:bg-primary-600': contained && primary,
    'bg-danger-500 hover:bg-danger-600': contained && danger,
    'bg-white border border-graySoft disabled:bg-grayCool-50': contained && !primaryOrDanger,
    border: outlined,
    'border-primary-500 hover:bg-primary-500': outlined && primary,
    'text-primary-500': outlineOrText && primary,
    'border-danger-500 hover:bg-danger-500': outlined && danger,
    'text-danger-500': outlineOrText && danger,
    'border-graySoft hover:bg-grayCool-50': outlined && !primaryOrDanger,
    'hover:bg-grayCool-50': contained && !primaryOrDanger || text,
    'text-gray': !primaryOrDanger,
    'ring-offset-2': (contained || outlined) && primaryOrDanger,
    'h-8': size === 'small',
    'h-10': size === 'medium',
    'h-12': size === 'large',
    'rounded-full': rounded,
    'rounded-lg': !rounded
  });
};

function ButtonComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      rounded = _ref.rounded,
      _ref$primary = _ref.primary,
      primary = _ref$primary === void 0 ? false : _ref$primary,
      _ref$danger = _ref.danger,
      danger = _ref$danger === void 0 ? false : _ref$danger,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'contained' : _ref$variant,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      startIcon = _ref.startIcon,
      endIcon = _ref.endIcon,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "rounded", "primary", "danger", "variant", "size", "startIcon", "endIcon"]);

  var small = size === 'small';
  var medium = size === 'medium';
  var large = size === 'large';
  var iconClassNames = classNames({
    'w-4 h-4': small,
    'w-5 h-5': medium,
    'w-6 h-6': large
  });
  var prefixIcon = startIcon ? cloneElement(startIcon, {
    className: classNames({
      'mr-2': small,
      'mr-3': medium || large
    }, iconClassNames)
  }) : null;
  var suffixIcon = endIcon ? cloneElement(endIcon, {
    className: classNames({
      'ml-2': small,
      'ml-3': medium || large
    }, iconClassNames)
  }) : null;
  return jsxs(Button$1, Object.assign({
    as: Type,
    className: classNames('flex items-center', {
      'pl-3': small && startIcon,
      'pl-4': medium && startIcon || small && !startIcon,
      'pl-5': large && startIcon || medium && !startIcon,
      'pl-6': large && !startIcon,
      'pr-3': small && endIcon,
      'pr-4': medium && endIcon || small && !endIcon,
      'pr-5': large && endIcon || medium && !endIcon,
      'pr-6': large && !endIcon
    }, buttonClasses(variant, size, primary, danger, rounded), className)
  }, props, {
    ref: ref
  }, {
    children: [prefixIcon, children, suffixIcon]
  }), void 0);
}

var Button = /*#__PURE__*/forwardRefWithAs(ButtonComponent);

function IconButtonComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      _ref$rounded = _ref.rounded,
      rounded = _ref$rounded === void 0 ? true : _ref$rounded,
      _ref$primary = _ref.primary,
      primary = _ref$primary === void 0 ? false : _ref$primary,
      _ref$danger = _ref.danger,
      danger = _ref$danger === void 0 ? false : _ref$danger,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'text' : _ref$variant,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "rounded", "primary", "danger", "variant", "size"]);

  var icon = cloneElement(children, {
    className: classNames({
      'w-4 h-4': size === 'small',
      'w-5 h-5': size === 'medium',
      'w-6 h-6': size === 'large'
    })
  });
  return jsx(Button$1, Object.assign({
    as: Type,
    className: classNames('flex items-center justify-center', {
      'w-8': size === 'small',
      'w-10': size === 'medium',
      'w-12': size === 'large'
    }, buttonClasses(variant, size, primary, danger, rounded), className)
  }, props, {
    ref: ref
  }, {
    children: icon
  }), void 0);
}

var IconButton = /*#__PURE__*/forwardRefWithAs(IconButtonComponent);

function CardLink(_ref) {
  var children = _ref.children,
      href = _ref.href,
      className = _ref.className;
  return jsx("a", Object.assign({
    className: classNames('text-gray tracking-wider uppercase', className),
    href: href
  }, {
    children: children
  }), void 0);
}
CardLink.defaultProps = {
  children: null,
  href: '#',
  className: null
};

function CardTitle(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return jsx("h2", Object.assign({
    className: classNames('text-lg font-medium text-grayDark', className)
  }, {
    children: children
  }), void 0);
}
CardTitle.defaultProps = {
  children: null,
  className: null
};

function Card(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return jsx("div", Object.assign({
    className: classNames('rounded-lg bg-white shadow-big', className)
  }, {
    children: children
  }), void 0);
}
Card.Title = CardTitle;
Card.Link = CardLink;
Card.defaultProps = {
  children: null,
  className: null
};

function CheckboxComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'input' : _ref$as,
      checked = _ref.checked,
      className = _ref.className,
      customClassName = _ref.customClassName,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "checked", "className", "customClassName"]);

  return jsx(Checkbox$1, Object.assign({
    as: Type,
    checked: checked,
    className: classNames({
      'checkbox w-4 h-4 rounded border-graySoft appearance-none border focus:outline-none focus:ring-2 ring-offset-2 ring-primary-500 checked:border-primary-500 checked:bg-primary-500': !customClassName
    }, customClassName, className)
  }, props, {
    ref: ref
  }), void 0);
}

var Checkbox = /*#__PURE__*/forwardRefWithAs(CheckboxComponent);

var DropdownContext = /*#__PURE__*/createContext(null);

function DropdownButton(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  var state = useContext(DropdownContext);
  return jsx(MenuButton, Object.assign({
    className: "group focus:outline-none"
  }, state, props, {
    children: children
  }), void 0);
}

function DropdownItemComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className"]);

  var state = useContext(DropdownContext);
  return jsx(MenuItem, Object.assign({
    as: Type,
    className: classNames('block w-full text-left px-4 py-2 focus:outline-none text-grayDark focus:bg-graySoft focus:bg-opacity-25', className)
  }, state, props, {
    ref: ref
  }, {
    children: children
  }), void 0);
}

var DropdownItem = /*#__PURE__*/forwardRefWithAs(DropdownItemComponent);

function DropdownList(_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  var state = useContext(DropdownContext);
  return jsx(Menu, Object.assign({
    className: classNames('transition-opacity w-48 py-1 rounded-lg shadow-soft bg-white focus:outline-none z-20 data-enter:opacity-100 opacity-0', className)
  }, state, props, {
    children: children
  }), void 0);
}

function DropdownSeparator(_ref) {
  var props = _extends({}, _ref);

  var state = useContext(DropdownContext);
  return jsx(MenuSeparator, Object.assign({}, state, props), void 0);
}

function Dropdown(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? {} : _ref$options;
  var state = useMenuState(_extends({
    animated: true,
    placement: 'bottom-end',
    gutter: 8
  }, options));
  return jsx("div", Object.assign({
    className: className
  }, {
    children: jsx(DropdownContext.Provider, Object.assign({
      value: state
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Dropdown.defaultProps = {
  children: null,
  className: null,
  options: {}
};
Dropdown.Button = DropdownButton;
Dropdown.Item = DropdownItem;
Dropdown.List = DropdownList;
Dropdown.Separator = DropdownSeparator;

var inputClasses = function inputClasses(disabled, isInvalid, isValid, border, focusWithin) {
  return classNames('px-4 focus:outline-none', {
    'bg-grayCool-100': disabled,
    'border-graySoft ring-primary-500': !isInvalid && !isValid && border,
    'border-transparent ring-danger-500 ring-2': isInvalid && border,
    'border-transparent ring-success-500 ring-2': isValid && border,
    'rounded-lg border transition': border,
    'focus:border-transparent focus:ring-2': !focusWithin && border,
    'focus-within:border-transparent focus-within:ring-2': focusWithin && border
  });
};

var Input = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var className = _ref.className,
      disabled = _ref.disabled,
      _ref$isInvalid = _ref.isInvalid,
      isInvalid = _ref$isInvalid === void 0 ? false : _ref$isInvalid,
      _ref$isValid = _ref.isValid,
      isValid = _ref$isValid === void 0 ? false : _ref$isValid,
      _ref$border = _ref.border,
      border = _ref$border === void 0 ? true : _ref$border,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "disabled", "isInvalid", "isValid", "border"]);

  return jsx(Input$1, Object.assign({
    className: classNames('h-10', inputClasses(disabled, isInvalid, isValid, border), className),
    disabled: disabled,
    ref: ref
  }, props), void 0);
});

var TextareaInput = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var className = _ref.className,
      _ref$resize = _ref.resize,
      resize = _ref$resize === void 0 ? 'none' : _ref$resize,
      disabled = _ref.disabled,
      isInvalid = _ref.isInvalid,
      isValid = _ref.isValid,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "resize", "disabled", "isInvalid", "isValid"]);

  return jsx("textarea", Object.assign({
    className: classNames('py-2', {
      'resize-none': resize === 'none',
      resize: resize === 'both',
      'resize-y': resize === 'vertical',
      'resize-x': resize === 'horizontal'
    }, inputClasses(disabled, isInvalid, isValid, true), className),
    disabled: disabled,
    ref: ref
  }, props), void 0);
});

function Label(_ref) {
  var className = _ref.className,
      children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "children"]);

  return jsx("label", Object.assign({
    className: classNames('text-grayDark', className)
  }, props, {
    children: children
  }), void 0);
}

var MediaContext = /*#__PURE__*/createContext({
  size: 'medium'
});

function MediaBody(_ref) {
  var children = _ref.children,
      className = _ref.className,
      margin = _ref.margin;

  var _useContext = useContext(MediaContext),
      size = _useContext.size;

  return jsx("div", Object.assign({
    className: classNames('flex-1', {
      'ml-4': size === 'medium' && !margin,
      'ml-6': size === 'large' && !margin
    }, margin, className)
  }, {
    children: children
  }), void 0);
}
MediaBody.defaultProps = {
  children: undefined,
  className: '',
  margin: undefined
};

function MediaDesc(_ref) {
  var children = _ref.children,
      className = _ref.className,
      margin = _ref.margin;

  var _useContext = useContext(MediaContext),
      size = _useContext.size;

  return jsx("div", Object.assign({
    className: classNames({
      'mt-2': size === 'medium' && !margin,
      'mt-3': size === 'large' && !margin
    }, margin, className)
  }, {
    children: children
  }), void 0);
}
MediaDesc.defaultProps = {
  children: undefined,
  className: '',
  margin: undefined
};

function MediaNumber(_ref) {
  var children = _ref.children;
  return jsx("span", Object.assign({
    className: "text-2xl w-14 text-primary-800"
  }, {
    children: children
  }), void 0);
}
MediaNumber.defaultProps = {
  children: null
};

function MediaThumbnail(_ref) {
  var src = _ref.src,
      alt = _ref.alt,
      size = _ref.size,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className;
  var context = useContext(MediaContext);
  return jsx("img", {
    alt: alt,
    className: classNames('object-cover rounded-lg', {
      'w-16 h-16': context.size === 'medium' && !size,
      'w-20 h-20': context.size === 'large' && !size
    }, size, className),
    src: src
  }, void 0);
}
MediaThumbnail.defaultProps = {
  size: undefined,
  className: ''
};

function MediaTitle(_ref) {
  var children = _ref.children,
      className = _ref.className,
      align = _ref.align;

  var _useContext = useContext(MediaContext),
      size = _useContext.size;

  return jsx("h3", Object.assign({
    className: classNames('text-grayDark', {
      'text-base': size === 'large',
      'text-left': !align
    }, align, className)
  }, {
    children: children
  }), void 0);
}
MediaTitle.defaultProps = {
  children: undefined,
  className: '',
  align: undefined
};

function Media(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'medium' : _ref$size;
  return jsx("div", Object.assign({
    className: classNames('flex items-center', className)
  }, {
    children: jsx(MediaContext.Provider, Object.assign({
      value: {
        size: size
      }
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Media.defaultProps = {
  children: null,
  className: null,
  size: 'medium'
};
Media.Body = MediaBody;
Media.Desc = MediaDesc;
Media.Number = MediaNumber;
Media.Title = MediaTitle;
Media.Thumbnail = MediaThumbnail;

var ModalContext = /*#__PURE__*/createContext(null);

function ModalButton(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  var state = useContext(ModalContext);
  return jsx(DialogDisclosure, Object.assign({}, state, props, {
    children: children
  }), void 0);
}

function ModalDialog(_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  var state = useContext(ModalContext);
  return jsx(DialogBackdrop, Object.assign({}, state, {
    className: "fixed top-0 left-0 z-30 flex w-full h-full duration-300 bg-black bg-opacity-0 transition-background-opacity data-enter:bg-opacity-60"
  }, {
    children: jsx(Dialog, Object.assign({
      className: classNames('transition-opacity my-auto duration-300 opacity-0 data-enter:opacity-100 focus:outline-none mx-auto bg-white rounded-xl p-6', className)
    }, state, props, {
      tabIndex: 0
    }, {
      children: children
    }), void 0)
  }), void 0);
}

function Modal(_ref) {
  var children = _ref.children,
      className = _ref.className,
      modalState = _ref.modalState;
  return jsx(ModalContext.Provider, Object.assign({
    value: modalState
  }, {
    children: jsx("div", Object.assign({
      className: className
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Modal.defaultProps = {
  children: null,
  className: null,
  options: {}
};
Modal.Button = ModalButton;
Modal.Dialog = ModalDialog;

function PageTitle(_ref) {
  var text = _ref.text,
      className = _ref.className;
  return jsx("h1", Object.assign({
    className: classNames('text-4xl tracking-wide font-medium text-grayDark', className)
  }, {
    children: text
  }), void 0);
}
PageTitle.defaultProps = {
  className: null
};

var PaginationContext = /*#__PURE__*/createContext({
  state: null,
  currentPage: 0
});

function PaginationButtonComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'button' : _ref$as,
      number = _ref.number,
      children = _ref.children,
      className = _ref.className,
      active = _ref.active,
      disabled = _ref.disabled,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "number", "children", "className", "active", "disabled"]);

  var _useContext = useContext(PaginationContext),
      state = _useContext.state,
      currentPage = _useContext.currentPage;

  var isActive = currentPage === number || active;
  return jsx(CompositeItem, Object.assign({
    as: Type,
    className: classNames('h-10 w-10 focus:outline-none focus:ring-2 ring-primary-500 rounded-full flex items-center justify-center', {
      'text-primary-500 font-medium': isActive,
      'text-gray': !isActive,
      'text-graySoft': disabled
    }, className),
    disabled: disabled,
    ref: ref
  }, state, props, {
    children: number || children
  }), void 0);
}

var PaginationButton = /*#__PURE__*/forwardRefWithAs(PaginationButtonComponent);

function Pagination(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$currentPage = _ref.currentPage,
      currentPage = _ref$currentPage === void 0 ? 0 : _ref$currentPage,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className", "currentPage"]);

  var state = useCompositeState({
    orientation: 'horizontal'
  });
  return jsx(Composite, Object.assign({
    className: classNames('flex', className)
  }, state, props, {
    children: jsx(PaginationContext.Provider, Object.assign({
      value: {
        state: state,
        currentPage: currentPage
      }
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Pagination.Button = PaginationButton;

function SelectButtonComponent(_ref, ref) {
  var className = _ref.className,
      children = _ref.children,
      isOpen = _ref.isOpen,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "children", "isOpen"]);

  return jsxs(Button$1, Object.assign({
    className: classNames('flex items-center w-full h-10 px-4 text-left bg-white border rounded-lg border-graySoft focus:outline-none focus:ring-2 focus-within:ring-2 ring-primary-500 disabled:bg-opacity-75 cursor-default', className)
  }, props, {
    ref: ref
  }, {
    children: [children, jsx("svg", Object.assign({
      className: classNames('w-5 h-5 ml-auto transition-transform transform text-gray', {
        'rotate-180': isOpen
      }),
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round",
      viewBox: "0 0 24 24",
      xmlns: "http://www.w3.org/2000/svg"
    }, {
      children: jsx("polyline", {
        points: "6 9 12 15 18 9"
      }, void 0)
    }), void 0)]
  }), void 0);
}

var SelectButton = /*#__PURE__*/forwardRef(SelectButtonComponent);

function SelectListComponent(_ref, ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  return jsx("ul", Object.assign({
    className: classNames('transition-opacity w-full py-1 rounded-lg shadow-soft bg-white focus:outline-none z-20 absolute', className)
  }, props, {
    ref: ref
  }, {
    children: children
  }), void 0);
}

var SelectList = /*#__PURE__*/forwardRef(SelectListComponent);

function SelectOptionComponent(_ref, ref) {
  var children = _ref.children,
      className = _ref.className,
      highlighted = _ref.highlighted,
      selected = _ref.selected,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className", "value", "highlighted", "selected"]);

  return jsx("li", Object.assign({
    className: classNames('block w-full text-left px-4 py-2 focus:outline-none cursor-default', {
      'bg-graySoft bg-opacity-25': highlighted && !selected,
      'bg-primary-600': highlighted && selected,
      'text-grayDark': !selected,
      'bg-primary-500 text-white': selected
    }, className)
  }, props, {
    ref: ref
  }, {
    children: children
  }), void 0);
}

var SelectOption = /*#__PURE__*/forwardRef(SelectOptionComponent);

function Combobox(_ref) {
  var className = _ref.className,
      placeholder = _ref.placeholder,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      onChange = _ref.onChange,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options;

  var _useState = useState(options),
      inputItems = _useState[0],
      setInputItems = _useState[1];

  var _useCombobox = useCombobox({
    items: inputItems,
    itemToString: function itemToString(item) {
      return !!(item != null && item.label) ? item.label : '';
    },
    onSelectedItemChange: function onSelectedItemChange(_ref2) {
      var selectedItem = _ref2.selectedItem;
      return onChange == null ? void 0 : onChange(selectedItem);
    },
    onInputValueChange: function onInputValueChange(_ref3) {
      var inputValue = _ref3.inputValue;
      setInputItems(options.filter(function (item) {
        return item.label.toLowerCase().includes(inputValue ? inputValue.toLowerCase() : '');
      }));
    },
    selectedItem: value,
    defaultSelectedItem: defaultValue
  }),
      isOpen = _useCombobox.isOpen,
      getToggleButtonProps = _useCombobox.getToggleButtonProps,
      getMenuProps = _useCombobox.getMenuProps,
      getItemProps = _useCombobox.getItemProps,
      getInputProps = _useCombobox.getInputProps,
      getComboboxProps = _useCombobox.getComboboxProps,
      highlightedIndex = _useCombobox.highlightedIndex,
      selectedItem = _useCombobox.selectedItem,
      setInputValue = _useCombobox.setInputValue;

  useEffect(function () {
    setInputItems(options);
  }, [options]);
  useEffect(function () {
    setInputValue('');
  }, [selectedItem]);
  return jsxs("div", Object.assign({
    className: classNames('relative focus:outline-none', className)
  }, {
    children: [jsx("div", Object.assign({}, getComboboxProps(), {
      children: jsx(SelectButton, Object.assign({
        className: classNames({
          'text-grayDark': selectedItem,
          'text-gray': !selectedItem
        }),
        isOpen: isOpen
      }, getToggleButtonProps(), {
        children: jsx("input", Object.assign({
          className: "w-full h-full appearance-none focus:outline-none placeholder-grayDark",
          placeholder: (selectedItem == null ? void 0 : selectedItem.label) || placeholder
        }, getInputProps()), void 0)
      }), void 0)
    }), void 0), jsx("div", Object.assign({
      className: classNames('focus:outline-none transition transform duration-300', {
        'opacity-0 translate-y-2': !isOpen,
        'opacity-100 translate-y-0': isOpen
      })
    }, getMenuProps(), {
      children: isOpen && jsx(SelectList, Object.assign({
        className: "mt-2"
      }, {
        children: inputItems.map(function (item, index) {
          return jsx(SelectOption, Object.assign({
            highlighted: highlightedIndex === index,
            selected: (selectedItem == null ? void 0 : selectedItem.value) === item.value
          }, getItemProps({
            item: item,
            index: index
          }), {
            children: item.label
          }), item.value);
        })
      }), void 0)
    }), void 0)]
  }), void 0);
}

function Select(_ref) {
  var className = _ref.className,
      placeholder = _ref.placeholder,
      defaultValue = _ref.defaultValue,
      value = _ref.value,
      onChange = _ref.onChange,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options;

  var _useState = useState(options),
      inputItems = _useState[0],
      setInputItems = _useState[1];

  var _useSelect = useSelect({
    items: options,
    itemToString: function itemToString(item) {
      return !!(item != null && item.label) ? item.label : '';
    },
    onSelectedItemChange: function onSelectedItemChange(_ref2) {
      var selectedItem = _ref2.selectedItem;
      return onChange == null ? void 0 : onChange(selectedItem);
    },
    selectedItem: value,
    defaultSelectedItem: defaultValue
  }),
      isOpen = _useSelect.isOpen,
      selectedItem = _useSelect.selectedItem,
      getToggleButtonProps = _useSelect.getToggleButtonProps,
      getMenuProps = _useSelect.getMenuProps,
      highlightedIndex = _useSelect.highlightedIndex,
      getItemProps = _useSelect.getItemProps;

  useEffect(function () {
    setInputItems(options);
  }, [options]);
  return jsxs("div", Object.assign({
    className: classNames('relative focus:outline-none', className)
  }, {
    children: [jsx(SelectButton, Object.assign({
      className: classNames({
        'text-grayDark': selectedItem,
        'text-gray': !selectedItem
      }),
      isOpen: isOpen
    }, getToggleButtonProps(), {
      children: (selectedItem == null ? void 0 : selectedItem.label) || placeholder
    }), void 0), jsx("div", Object.assign({
      className: classNames('focus:outline-none transition transform duration-300 relative z-20', {
        'opacity-0 translate-y-2': !isOpen,
        'opacity-100 translate-y-0': isOpen
      })
    }, getMenuProps(), {
      children: isOpen && jsx(SelectList, Object.assign({
        className: "mt-2"
      }, {
        children: inputItems.map(function (item, index) {
          return jsx(SelectOption, Object.assign({
            highlighted: highlightedIndex === index,
            selected: (selectedItem == null ? void 0 : selectedItem.value) === item.value
          }, getItemProps({
            item: item,
            index: index
          }), {
            children: item.label
          }), item.value);
        })
      }), void 0)
    }), void 0)]
  }), void 0);
}
Select.defaultProps = {
  children: null,
  className: '',
  placeholder: '',
  defaultValue: undefined,
  options: []
};

function Separator(_ref) {
  var className = _ref.className,
      _ref$orientation = _ref.orientation,
      orientation = _ref$orientation === void 0 ? 'horizontal' : _ref$orientation,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "orientation"]);

  return jsx(Separator$1, Object.assign({
    className: classNames('border-t border-graySoft', className),
    orientation: orientation
  }, props), void 0);
}

var SidenavCompositeContext = /*#__PURE__*/createContext(null);
var SidenavSubDisclosureContext = /*#__PURE__*/createContext(null);
var SidenavSubCompositeContext = /*#__PURE__*/createContext(null);

function SidenavItemComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'a' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      icon = _ref.icon,
      active = _ref.active,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "icon", "active"]);

  var iconEl = null;
  var state = useContext(SidenavCompositeContext);

  if (icon) {
    iconEl = cloneElement(icon, {
      className: 'w-5 h-5 mr-5'
    });
  }

  return jsx("li", {
    children: jsxs(CompositeItem, Object.assign({
      as: Type,
      className: classNames('w-full h-14 px-4 rounded-lg tracking-wider flex items-center transition focus:outline-none focus:ring-2 ring-primary-500', {
        'bg-white bg-opacity-10 text-white font-medium': active,
        'text-primary-50 hover:bg-white hover:bg-opacity-5': !active
      }, className)
    }, props, state, {
      ref: ref
    }, {
      children: [iconEl, children]
    }), void 0)
  }, void 0);
}

var SidenavItem = /*#__PURE__*/forwardRefWithAs(SidenavItemComponent);

function SidenavList(_ref) {
  var title = _ref.title,
      children = _ref.children,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className;
  return jsxs("div", Object.assign({
    className: classNames('last:pb-8', {
      'pt-6': !className.includes('pt-')
    }, className)
  }, {
    children: [title && jsx("h3", Object.assign({
      className: classNames('px-10 text-xs tracking-widest uppercase text-white text-opacity-80')
    }, {
      children: title
    }), void 0), jsx(Role, Object.assign({
      as: "ul",
      className: "px-4 mt-4 space-y-4"
    }, {
      children: children
    }), void 0)]
  }), void 0);
}

function SidenavListContainer(_ref) {
  var children = _ref.children,
      className = _ref.className;
  return jsx("div", Object.assign({
    style: {
      height: 'calc(100vh - 5rem)'
    },
    className: classNames('overflow-auto', className)
  }, {
    children: children
  }), void 0);
}

function SidenavTitle(_ref) {
  var children = _ref.children,
      href = _ref.href;
  return jsx("a", Object.assign({
    className: "flex items-center justify-center h-20 text-lg font-medium tracking-wider text-white focus:outline-none",
    href: href
  }, {
    children: children
  }), void 0);
}
SidenavTitle.defaultProps = {
  href: '#'
};

function SidenavSub(_ref) {
  var children = _ref.children;
  var state = useDisclosureState({
    animated: true
  });
  return jsx(SidenavSubDisclosureContext.Provider, Object.assign({
    value: state
  }, {
    children: jsx("li", {
      children: children
    }, void 0)
  }), void 0);
}

function SidenavSubItemComponent(_ref, ref) {
  var _ref$as = _ref.as,
      Type = _ref$as === void 0 ? 'a' : _ref$as,
      children = _ref.children,
      className = _ref.className,
      active = _ref.active,
      props = _objectWithoutPropertiesLoose(_ref, ["as", "children", "className", "active"]);

  var state = useContext(SidenavSubCompositeContext);
  return jsx("li", {
    children: jsx(CompositeItem, Object.assign({
      as: Type,
      className: classNames('w-full h-14 pl-14 pr-4 rounded-lg tracking-wider flex items-center transition focus:outline-none focus:ring-2 ring-primary-500', {
        'bg-white bg-opacity-10 text-white font-medium': active,
        'text-primary-50 hover:bg-white hover:bg-opacity-5': !active
      }, className)
    }, props, state, {
      ref: ref
    }, {
      children: children
    }), void 0)
  }, void 0);
}

var SidenavSubItem = /*#__PURE__*/forwardRefWithAs(SidenavSubItemComponent);

function SidenavSubList(_ref) {
  var children = _ref.children,
      className = _ref.className;

  var _useState = useState(0),
      height = _useState[0],
      setHeight = _useState[1];

  var disclosure = useContext(SidenavSubDisclosureContext);
  var composite = useCompositeState({
    orientation: 'vertical'
  });
  useEffect(function () {
    if (disclosure != null && disclosure.animating) {
      if (disclosure.visible) setHeight('auto');else setHeight(0);
    }
  }, [disclosure == null ? void 0 : disclosure.animating]);
  return jsx(DisclosureContent, Object.assign({
    as: AnimateHeight
  }, disclosure, {
    duration: 300,
    height: height
  }, {
    children: jsx(SidenavSubCompositeContext.Provider, Object.assign({
      value: composite
    }, {
      children: jsx(Composite, Object.assign({
        as: "ul",
        "aria-label": "Sidenav submenu",
        className: classNames('mt-2 space-y-2', className),
        role: "menu"
      }, composite, {
        children: children
      }), void 0)
    }), void 0)
  }), void 0);
}

function SidenavSubTogglerComponent(_ref, ref) {
  var children = _ref.children,
      className = _ref.className,
      icon = _ref.icon,
      active = _ref.active,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className", "icon", "active"]);

  var disclosure = useContext(SidenavSubDisclosureContext);
  var iconEl = null;
  var composite = useContext(SidenavCompositeContext);

  if (icon) {
    iconEl = cloneElement(icon, {
      className: 'w-5 h-5 mr-5'
    });
  }

  return jsxs(CompositeItem, Object.assign({
    as: Disclosure,
    className: classNames('w-full h-14 px-4 rounded-lg tracking-wider flex items-center transition focus:outline-none focus:ring-2 ring-primary-500', {
      'bg-white bg-opacity-10 text-white font-medium': active,
      'text-primary-50 hover:bg-white hover:bg-opacity-5': !active
    }, className)
  }, props, disclosure, composite, {
    ref: ref
  }, {
    children: [iconEl, children, jsx("svg", Object.assign({
      xmlns: "http://www.w3.org/2000/svg",
      className: classNames('w-5 h-5 ml-auto transition-all transform duration-300', {
        'rotate-180': disclosure == null ? void 0 : disclosure.visible
      }),
      viewBox: "0 0 24 24",
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round"
    }, {
      children: jsx("polyline", {
        points: "6 9 12 15 18 9"
      }, void 0)
    }), void 0)]
  }), void 0);
}

var SidenavSubToggler = /*#__PURE__*/forwardRefWithAs(SidenavSubTogglerComponent);

function Sidenav(_ref) {
  var _ref$open = _ref.open,
      open = _ref$open === void 0 ? true : _ref$open,
      handleClose = _ref.handleClose,
      children = _ref.children,
      className = _ref.className;
  var dialog = useDialogState({
    animated: true,
    visible: open,
    modal: false
  });
  var composite = useCompositeState({
    orientation: 'vertical'
  });
  useEffect(function () {
    dialog.setVisible(open);
  }, [dialog, open]);
  return jsxs(Fragment, {
    children: [jsx(Dialog, Object.assign({}, dialog, {
      "aria-label": "Sidebar",
      as: "aside",
      className: classNames('group fixed top-0 lg:sticky bg-primary-900 transition-margin duration-300 h-full min-h-screen w-72 flex-shrink-0 -ml-72 data-enter:ml-0 shadow-md z-40 focus:outline-none', className),
      hideOnEsc: function () {
        return window.innerWidth <= 768;
      }(),
      hideOnClickOutside: function () {
        return window.innerWidth <= 768;
      }(),
      style: {
        willChange: 'margin'
      }
    }, {
      children: jsx("nav", {
        children: jsx(SidenavCompositeContext.Provider, Object.assign({
          value: composite
        }, {
          children: jsx(Composite, Object.assign({}, composite, {
            "aria-label": "Sidenav menu",
            role: "menu"
          }, {
            children: children
          }), void 0)
        }), void 0)
      }, void 0)
    }), void 0), jsx(DialogBackdrop, Object.assign({}, dialog, {
      className: "fixed z-30 w-full h-full duration-300 bg-black bg-opacity-0 lg:w-0 transition-background-opacity data-enter:bg-opacity-60",
      onClick: function onClick() {
        return handleClose == null ? void 0 : handleClose();
      }
    }), void 0)]
  }, void 0);
}
Sidenav.defaultProps = {
  open: true,
  handleClose: function handleClose() {},
  children: null,
  className: ''
};
Sidenav.Item = SidenavItem;
Sidenav.List = SidenavList;
Sidenav.ListContainer = SidenavListContainer;
Sidenav.Sub = SidenavSub;
Sidenav.SubItem = SidenavSubItem;
Sidenav.SubList = SidenavSubList;
Sidenav.SubToggler = SidenavSubToggler;
Sidenav.Title = SidenavTitle;

function StatsDesc(_ref) {
  var text = _ref.text,
      icon = _ref.icon,
      className = _ref.className;
  var iconEl = icon ? cloneElement(icon, {
    className: classNames('w-4 h-4 mr-2', className)
  }) : null;
  return jsxs("span", Object.assign({
    className: classNames('flex items-center text-gray', className)
  }, {
    children: [iconEl, text]
  }), void 0);
}
StatsDesc.defaultProps = {
  text: null,
  icon: null,
  className: null
};

function TableBody(_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  return jsx("tbody", Object.assign({
    className: classNames('divide-y divide-graySoft', className)
  }, props, {
    children: children
  }), void 0);
}

function TableCell(_ref) {
  var children = _ref.children,
      _ref$align = _ref.align,
      align = _ref$align === void 0 ? 'left' : _ref$align,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "align", "className"]);

  return jsx("td", Object.assign({
    className: classNames('px-6 py-4 whitespace-nowrap', {
      'text-left': align === 'left',
      'text-right': align === 'right',
      'text-center': align === 'center'
    }, className)
  }, props, {
    children: children
  }), void 0);
}

var TableContext = /*#__PURE__*/createContext({
  variant: 'normal'
});

function TableFoot(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  return jsx("tfoot", Object.assign({}, props, {
    children: children
  }), void 0);
}

function TableHead(_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  return jsx("thead", Object.assign({
    className: classNames('border-b border-graySoft', className)
  }, props, {
    children: children
  }), void 0);
}

function TableHeading(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$align = _ref.align,
      align = _ref$align === void 0 ? 'left' : _ref$align,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className", "align"]);

  return jsx("th", Object.assign({
    className: classNames('px-6 py-3 font-medium tracking-wider text-grayDark', {
      'text-left': align === 'left',
      'text-right': align === 'right',
      'text-center': align === 'center'
    }, className)
  }, props, {
    children: children
  }), void 0);
}

function TableRow(_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  var variant = useContext(TableContext).variant;
  return jsx("tr", Object.assign({
    className: classNames({
      'even:bg-grayCool-50': variant === 'striped'
    }, className)
  }, props, {
    children: children
  }), void 0);
}

function Table(_ref) {
  var _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'normal' : _ref$variant,
      children = _ref.children,
      className = _ref.className;
  return jsx(TableContext.Provider, Object.assign({
    value: {
      variant: variant
    }
  }, {
    children: jsx("table", Object.assign({
      className: classNames('w-full', className)
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Table.Body = TableBody;
Table.Cell = TableCell;
Table.Foot = TableFoot;
Table.Head = TableHead;
Table.Heading = TableHeading;
Table.Row = TableRow;

var TabsContext = /*#__PURE__*/createContext(null);

function TabsButton(_ref) {
  var _button$current, _button$current2;

  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  var state = useContext(TabsContext);
  var button = useRef(null);
  var active = ((_button$current = button.current) == null ? void 0 : _button$current.id) && ((_button$current2 = button.current) == null ? void 0 : _button$current2.id) === (state == null ? void 0 : state.selectedId);
  return jsxs(Tab, Object.assign({
    className: classNames('focus:outline-none group', {
      'font-medium text-grayDark': active,
      'text-gray': !active
    }, className)
  }, state, props, {
    ref: button
  }, {
    children: [jsx("div", Object.assign({
      className: "tracking-wider rounded-lg group-focus:ring-2 ring-primary-500 ring-offset-2"
    }, {
      children: children
    }), void 0), jsx("div", {
      className: classNames('w-full h-1 mt-3.5', {
        'bg-primary-500': active
      })
    }, void 0)]
  }), void 0);
}

function TabsMenu(_ref) {
  var className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["className"]);

  var state = useContext(TabsContext);
  return jsx(TabList, Object.assign({
    className: classNames('flex space-x-10', className)
  }, state, props), void 0);
}

function TabsPanel(_ref) {
  var className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["className"]);

  var state = useContext(TabsContext);
  return jsx(TabPanel, Object.assign({
    className: classNames('focus:outline-none', className)
  }, state, props), void 0);
}

function Tabs(_ref) {
  var children = _ref.children,
      className = _ref.className,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? {} : _ref$options,
      activeTab = _ref.activeTab;
  var state = useTabState(options);
  useEffect(function () {
    activeTab == null ? void 0 : activeTab(state.selectedId);
  }, [state.selectedId]);
  return jsx("div", Object.assign({
    className: className
  }, {
    children: jsx(TabsContext.Provider, Object.assign({
      value: state
    }, {
      children: children
    }), void 0)
  }), void 0);
}
Tabs.defaultProps = {
  children: null,
  className: null,
  options: {}
};
Tabs.Button = TabsButton;
Tabs.Menu = TabsMenu;
Tabs.Panel = TabsPanel;

function Toast(_ref) {
  var appearance = _ref.appearance,
      children = _ref.children,
      transitionState = _ref.transitionState,
      placement = _ref.placement,
      className = _ref.className;
  return jsxs("div", Object.assign({
    className: classNames('transform flex items-center py-4 pl-4 pr-5 text-white transition-all rounded-lg bg-primary-900', {
      'opacity-0 shadow-none': transitionState === 'entering' || transitionState === 'exiting',
      'ease-out': transitionState === 'entering',
      'ease-in': transitionState === 'exiting',
      '-translate-y-8': (transitionState === 'entering' || transitionState === 'exiting') && (placement == null ? void 0 : placement.includes('top')),
      'translate-y-8': (transitionState === 'entering' || transitionState === 'exiting') && (placement == null ? void 0 : placement.includes('bottom')),
      'translate-x-8': (transitionState === 'entering' || transitionState === 'exiting') && (placement == null ? void 0 : placement.includes('right')),
      '-translate-x-8': (transitionState === 'entering' || transitionState === 'exiting') && (placement == null ? void 0 : placement.includes('left')),
      'opacity-100 translate-x-0 translate-y-0 shadow-soft': transitionState === 'entered' || transitionState === 'exited'
    }, className)
  }, {
    children: [appearance === 'error' && jsxs("svg", Object.assign({
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 24 24",
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round",
      className: "w-5 h-5 mr-4 text-danger-500"
    }, {
      children: [jsx("path", {
        d: "M10.29 3.86L1.82 18a2 2 0 0 0 1.71 3h16.94a2 2 0 0 0 1.71-3L13.71 3.86a2 2 0 0 0-3.42 0z"
      }, void 0), jsx("line", {
        x1: "12",
        y1: "9",
        x2: "12",
        y2: "13"
      }, void 0), jsx("line", {
        x1: "12",
        y1: "17",
        x2: "12.01",
        y2: "17"
      }, void 0)]
    }), void 0), appearance === 'info' && jsxs("svg", Object.assign({
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 24 24",
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round",
      className: "w-5 h-5 mr-4 text-info-500"
    }, {
      children: [jsx("circle", {
        cx: "12",
        cy: "12",
        r: "10"
      }, void 0), jsx("line", {
        x1: "12",
        y1: "16",
        x2: "12",
        y2: "12"
      }, void 0), jsx("line", {
        x1: "12",
        y1: "8",
        x2: "12.01",
        y2: "8"
      }, void 0)]
    }), void 0), appearance === 'success' && jsxs("svg", Object.assign({
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 24 24",
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round",
      className: "w-5 h-5 mr-4 text-success-500"
    }, {
      children: [jsx("path", {
        d: "M22 11.08V12a10 10 0 1 1-5.93-9.14"
      }, void 0), jsx("polyline", {
        points: "22 4 12 14.01 9 11.01"
      }, void 0)]
    }), void 0), appearance === 'warning' && jsxs("svg", Object.assign({
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 24 24",
      fill: "none",
      stroke: "currentColor",
      strokeWidth: "2",
      strokeLinecap: "round",
      strokeLinejoin: "round",
      className: "w-5 h-5 mr-4 text-warning-500"
    }, {
      children: [jsx("circle", {
        cx: "12",
        cy: "12",
        r: "10"
      }, void 0), jsx("line", {
        x1: "12",
        y1: "8",
        x2: "12",
        y2: "12"
      }, void 0), jsx("line", {
        x1: "12",
        y1: "16",
        x2: "12.01",
        y2: "16"
      }, void 0)]
    }), void 0), children]
  }), void 0);
}

function useModalState(options) {
  if (options === void 0) {
    options = {};
  }

  return useDialogState(_extends({
    animated: true
  }, options));
}

function useSelectState(options) {
  return useMenuState(_extends({
    animated: true,
    placement: 'bottom',
    gutter: 8
  }, options));
}

export { Alert, AlertIcon, AlertTitle, Avatar, Badge, Button, Card, Checkbox, Combobox, Dropdown, IconButton, Input, Label, Media, Modal, PageTitle, Pagination, Select, Separator, Sidenav, StatsDesc, Table, Tabs, TextareaInput, Toast, useModalState, useSelectState };
//# sourceMappingURL=react.esm.js.map
